@@ -1,5 +1,5 @@
 /*
-% Copyright (C) 2003 - 2010 GraphicsMagick Group
+% Copyright (C) 2003 - 2013 GraphicsMagick Group
 % Copyright (C) 2002 ImageMagick Studio
 %
 % This program is covered by multiple licenses, which are described in
@@ -367,6 +367,14 @@ MagickExport const DelegateInfo *GetPostscriptDelegateInfo(const ImageInfo *imag
     {
       (void) strlcpy(delegate,"gs-color+alpha",sizeof(delegate));
     }
+  else if (ColorSeparationType == image_info->type)
+    {
+      (void) strlcpy(delegate,"gs-cmyk",sizeof(delegate));
+    }
+  else if (ColorSeparationMatteType == image_info->type)
+    {
+      (void) strlcpy(delegate,"gs-cmyka",sizeof(delegate));
+    }
   return GetDelegateInfo(delegate,(char *) NULL,exception);
 }
 
@@ -641,7 +649,7 @@ MagickExport unsigned int InvokeDelegate(ImageInfo *image_info,Image *image,
         MagickFreeMemory(magick);
         (void) strlcpy(decode_filename,image->filename,MaxTextExtent);
         FormatString(clone_info->filename,"%.1024s:",delegate_info->decode);
-        (void) SetImageInfo(clone_info,MagickFalse,exception);
+        (void) SetImageInfo(clone_info,SETMAGICK_WRITE,exception);
         (void) strlcpy(clone_info->filename,image_info->filename,
           MaxTextExtent);
         for (p=image; p != (Image *) NULL; p=p->next)
@@ -959,6 +967,9 @@ InvokePostscriptDelegate(const unsigned int verbose,
 
   status=MagickFail;
   {
+    /*
+      Build Ghostscript command argument list
+    */
     argv = StringToArgv(command,&argc);
     if (argv == (char **) NULL)
       {
@@ -968,8 +979,22 @@ InvokePostscriptDelegate(const unsigned int verbose,
       }
     else
       {
-	if (MagickSpawnVP(verbose,argv[1],argv+1) == 0)
-	  status=MagickPass;
+        if (strlen(argv[1]) == 0)
+          {
+            /*
+              argv[1] can be empty under Windows due to empty
+              command substitution text.
+            */
+            ThrowException(exception,DelegateError,
+                           FailedToFindGhostscript,
+                           command);
+            status=MagickFail;
+          }
+        else
+          {
+            if (MagickSpawnVP(verbose,argv[1],argv+1) == 0)
+              status=MagickPass;
+          }
 	for (i=0; i < argc; i++)
 	  MagickFreeMemory(argv[i]);
 	MagickFreeMemory(argv);
@@ -1044,11 +1069,13 @@ MagickExport unsigned int ListDelegateInfo(FILE *file,ExceptionInfo *exception)
     if (commands == (char **) NULL)
       continue;
     {
+	  size_t
+        command_length,
+         length=0;
+
       int
         command_start_column,
-        command_length,
         formatted_chars=0,
-        length=0,
         screen_width=79,
         strip_length;
       
